@@ -17,12 +17,20 @@ import errno
 import io
 import json
 import os
-import tornado
+from typing import Any
+from typing import Dict
+from typing import List
+from typing import Optional
 
 from jsonschema import ValidationError
-from elyra.metadata import METADATA_TEST_NAMESPACE, Metadata, MetadataStore, FileMetadataStore, \
-    MetadataNotFoundError, MetadataExistsError
-from typing import Optional, List, Any
+
+from elyra.metadata.error import MetadataExistsError
+from elyra.metadata.error import MetadataNotFoundError
+from elyra.metadata.metadata import Metadata
+from elyra.metadata.schema import METADATA_TEST_NAMESPACE
+from elyra.metadata.schema import SchemaFilter
+from elyra.metadata.storage import FileMetadataStore
+from elyra.metadata.storage import MetadataStore
 
 
 valid_metadata_json = {
@@ -155,12 +163,14 @@ def create_file(location, file_name, content):
         f.write(content)
 
 
-def create_instance(metadata_store: MetadataStore, location: str, name: str, content: Any):
+def create_instance(metadata_store: MetadataStore, location: str, name: str, content: Any) -> str:
+    resource = name
     if isinstance(metadata_store, FileMetadataStore):
         if isinstance(content, dict):
             create_json_file(location, name + '.json', content)
         else:
             create_file(location, name + '.json', content)
+        resource = os.path.join(location, name + '.json')
     elif isinstance(metadata_store, MockMetadataStore):
         instances = metadata_store.instances
         if instances is None:
@@ -169,9 +179,10 @@ def create_instance(metadata_store: MetadataStore, location: str, name: str, con
         if not isinstance(content, dict):
             content = {'display_name': name, 'reason': "JSON failed to load for instance '{}'".format(name)}
         instances[name] = content
+    return resource
 
 
-def get_schema(schema_name):
+def get_unfiltered_schema(schema_name):
     schema_file = os.path.join(os.path.dirname(__file__), '..', 'schemas', schema_name + '.json')
     if not os.path.exists(schema_file):
         raise ValidationError("Metadata schema file '{}' is missing!".format(schema_file))
@@ -190,28 +201,6 @@ def get_instance(instances, field, value):
     assert False, "Value '{}' for field '{}' was not found in instances!".format(value, field)
 
 
-def expected_http_error(error, expected_code, expected_message=None):
-    """Check that the error matches the expected output error."""
-    e = error.value
-    if isinstance(e, tornado.web.HTTPError):
-        if expected_code != e.status_code:
-            return False
-        if expected_message is not None and expected_message != str(e):
-            return False
-        return True
-    elif any([
-        isinstance(e, tornado.httpclient.HTTPClientError),
-        isinstance(e, tornado.httpclient.HTTPError)
-    ]):
-        if expected_code != e.code:
-            return False
-        if expected_message:
-            message = json.loads(e.response.body.decode())['message']
-            if expected_message != message:
-                return False
-        return True
-
-
 class PropertyTester(object):
     """Helper class used by elyra_md tests to test each of the properties in the test.json schema. """
     name = None             # prefixed with 'test_' is test name, post-fixed with '_test' is schema property name
@@ -270,21 +259,18 @@ class MockMetadataStore(MetadataStore):
 
     def namespace_exists(self) -> bool:
         """Returns True if the namespace for this instance exists"""
-        if self.instances is not None:
-            return True
-        return False
+        return self.instances is not None
 
     def fetch_instances(self, name: Optional[str] = None, include_invalid: bool = False) -> List[dict]:
         """Fetch metadata instances"""
 
         if name:
-            if self.instances is not None:
-                if name in self.instances:
-                    instance = self.instances.get(name)
-                    if instance.get('reason'):
-                        raise ValueError(instance.get('reason'))
-                    instance['name'] = name
-                    return [instance]
+            if self.instances is not None and name in self.instances:
+                instance = self.instances.get(name)
+                if instance.get('reason'):
+                    raise ValueError(instance.get('reason'))
+                instance['name'] = name
+                return [instance]
             raise MetadataNotFoundError(self.namespace, name)
 
         # all instances are wanted, filter based on include-invalid and reason ...
@@ -361,3 +347,24 @@ class MockMetadataTestInvalid(object):
     """
     def __init__(self, **kwargs: Any) -> None:
         pass
+
+
+class TestSchemaFilter(SchemaFilter):
+    """Test schema filter to validate schema filtering """
+    def post_load(self, name: str, schema_json: Dict) -> Dict:
+        """Ensure tekton packages are present and remove engine from schema if not."""
+
+        filtered_schema = super().post_load(name, schema_json)
+
+        # Update multipleOf from 7 to 6 and and value 'added' to enum-valued property
+        multiple_of: int = \
+            filtered_schema['properties']['metadata']['properties']['integer_multiple_test']['multipleOf']
+        assert multiple_of == 7
+        filtered_schema['properties']['metadata']['properties']['integer_multiple_test']['multipleOf'] = 6
+
+        enum: list = filtered_schema['properties']['metadata']['properties']['enum_test']['enum']
+        assert len(enum) == 2
+        enum.append('added')
+        filtered_schema['properties']['metadata']['properties']['enum_test']['enum'] = enum
+
+        return filtered_schema
