@@ -16,8 +16,6 @@
 
 import json
 
-import pytest
-
 from elyra.pipeline.tests import resources
 
 # from jupyter_server.tests.utils import expected_http_error
@@ -30,18 +28,6 @@ except ImportError:
     import importlib_resources as pkg_resources
 
 
-# Set Elyra server extension as enabled (overriding server_config fixture from jupyter_server)
-@pytest.fixture
-def jp_server_config():
-    return {
-        "ServerApp": {
-            "jpserver_extensions": {
-                "elyra": True
-            }
-        }
-    }
-
-
 async def test_get_components(jp_fetch):
     # Ensure all valid components can be found
     response = await jp_fetch('elyra', 'pipeline', 'components', 'local')
